pub struct ListRootsParams {
pub meta: Option<RequestMeta>,
}Expand description
Sent from the server to request a list of root URIs from the client. Roots allow servers to ask for specific directories or files to operate on.
TS Ref: ListRootsRequest
Fields
meta: Option<RequestMeta>Optional metadata (_meta) for the request.