pub struct LoggingMessageNotificationParams {
pub meta: Option<GenericMeta>,
pub level: LoggingLevel,
pub logger: Option<String>,
pub data: Value,
}Expand description
Notification of a log message passed from server to client. If no logging/setLevel request has been sent from the client, the server MAY decide which messages to send automatically.
TS Ref: LoggingMessageNotification
Fields
meta: Option<GenericMeta>level: LoggingLevelThe severity of this log message.
logger: Option<String>An optional name of the logger issuing this message.
data: ValueThe data to be logged, such as a string message or an object. Any JSON serializable type is allowed here.
Implementations
Sourceimpl LoggingMessageNotificationParams
Builders
impl LoggingMessageNotificationParams
Builders
pub fn new(level: LoggingLevel, data: impl Into<Value>) -> Self
pub fn with_meta(self, meta: GenericMeta) -> Self
pub fn with_logger(self, logger: impl Into<String>) -> Self